Struct ByteRecords

struct ByteRecords<B> { ... }

An iterator over records from an instance of std::io::BufRead.

A byte record is any sequence of bytes terminated by a particular byte chosen by the caller. For example, NUL separated byte strings are said to be NUL-terminated byte records.

This iterator is generally created by calling the byte_records method on the BufReadExt trait.

Implementations

impl<B> Freeze for ByteRecords<B>

impl<B> RefUnwindSafe for ByteRecords<B>

impl<B> Send for ByteRecords<B>

impl<B> Sync for ByteRecords<B>

impl<B> Unpin for ByteRecords<B>

impl<B> UnsafeUnpin for ByteRecords<B>

impl<B> UnwindSafe for ByteRecords<B>

impl<B: $crate::fmt::Debug> Debug for ByteRecords<B>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<B: io::BufRead> Iterator for ByteRecords<B>

fn next(self: &mut Self) -> Option<Result<Vec<u8>>>

impl<I> IntoIterator for ByteRecords<B>

fn into_iter(self: Self) -> I

impl<T> Any for ByteRecords<B>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ByteRecords<B>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ByteRecords<B>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ByteRecords<B>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for ByteRecords<B>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ByteRecords<B>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ByteRecords<B>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>