Struct SplitN

struct SplitN<'h, 's> { ... }

An iterator over at most n substrings in a byte string, split by a separator.

'h is the lifetime of the byte string being split (the haystack), while 's is the lifetime of the byte string doing the splitting.

Implementations

impl<'h, 's> Clone for SplitN<'h, 's>

fn clone(self: &Self) -> SplitN<'h, 's>

impl<'h, 's> Debug for SplitN<'h, 's>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'h, 's> Freeze for SplitN<'h, 's>

impl<'h, 's> Iterator for SplitN<'h, 's>

fn next(self: &mut Self) -> Option<&'h [u8]>

impl<'h, 's> RefUnwindSafe for SplitN<'h, 's>

impl<'h, 's> Send for SplitN<'h, 's>

impl<'h, 's> Sync for SplitN<'h, 's>

impl<'h, 's> Unpin for SplitN<'h, 's>

impl<'h, 's> UnsafeUnpin for SplitN<'h, 's>

impl<'h, 's> UnwindSafe for SplitN<'h, 's>

impl<I> IntoIterator for SplitN<'h, 's>

fn into_iter(self: Self) -> I

impl<T> Any for SplitN<'h, 's>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SplitN<'h, 's>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SplitN<'h, 's>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SplitN<'h, 's>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SplitN<'h, 's>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SplitN<'h, 's>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SplitN<'h, 's>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SplitN<'h, 's>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SplitN<'h, 's>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>