Struct Find
struct Find<'h, 'n> { ... }
An iterator over non-overlapping substring matches.
Matches are reported by the byte offset at which they begin.
'h is the lifetime of the haystack while 'n is the lifetime of the
needle.
Implementations
impl<'h, 'n> Clone for Find<'h, 'n>
fn clone(self: &Self) -> Find<'h, 'n>
impl<'h, 'n> Debug for Find<'h, 'n>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'h, 'n> Freeze for Find<'h, 'n>
impl<'h, 'n> Iterator for Find<'h, 'n>
fn next(self: &mut Self) -> Option<usize>
impl<'h, 'n> RefUnwindSafe for Find<'h, 'n>
impl<'h, 'n> Send for Find<'h, 'n>
impl<'h, 'n> Sync for Find<'h, 'n>
impl<'h, 'n> Unpin for Find<'h, 'n>
impl<'h, 'n> UnsafeUnpin for Find<'h, 'n>
impl<'h, 'n> UnwindSafe for Find<'h, 'n>
impl<I> IntoIterator for Find<'h, 'n>
fn into_iter(self: Self) -> I
impl<T> Any for Find<'h, 'n>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Find<'h, 'n>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Find<'h, 'n>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Find<'h, 'n>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Find<'h, 'n>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Find<'h, 'n>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Find<'h, 'n>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Find<'h, 'n>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Find<'h, 'n>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>